aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.World/Random.cpp
diff options
context:
space:
mode:
authorvoid_17 <heroerror3@gmail.com>2026-03-02 15:53:32 +0700
committervoid_17 <heroerror3@gmail.com>2026-03-02 15:53:32 +0700
commitd63f79325f85e014361eb8cf1e41eaebedb1ae71 (patch)
treed9f28714afd516bc2450f33b0a77c5e05ff4de90 /Minecraft.World/Random.cpp
parentd6ec138710461294c3ffd2723bc8a9f212d3471f (diff)
Get rid of MSVC's __int64
Use either int64_t, uint64_t or long long and unsigned long long, defined as per C++11 standard
Diffstat (limited to 'Minecraft.World/Random.cpp')
-rw-r--r--Minecraft.World/Random.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/Minecraft.World/Random.cpp b/Minecraft.World/Random.cpp
index 9176bf38..d4e3a545 100644
--- a/Minecraft.World/Random.cpp
+++ b/Minecraft.World/Random.cpp
@@ -1,4 +1,4 @@
-#include "stdafx.h"
+#include "stdafx.h"
#include "Random.h"
#include "System.h"
@@ -6,19 +6,19 @@ Random::Random()
{
// 4J - jave now uses the system nanosecond counter added to a "seedUniquifier" to get an initial seed. Our nanosecond timer is actually only millisecond accuate, so
// use QueryPerformanceCounter here instead
- __int64 seed;
+ int64_t seed;
QueryPerformanceCounter((LARGE_INTEGER *)&seed);
seed += 8682522807148012LL;
setSeed(seed);
}
-Random::Random(__int64 seed)
+Random::Random(int64_t seed)
{
setSeed(seed);
}
-void Random::setSeed(__int64 s)
+void Random::setSeed(int64_t s)
{
this->seed = (s ^ 0x5DEECE66DLL) & ((1LL << 48) - 1);
haveNextNextGaussian = false;
@@ -41,7 +41,7 @@ void Random::nextBytes(byte *bytes, unsigned int count)
double Random::nextDouble()
{
- return (((__int64)next(26) << 27) + next(27))
+ return (((int64_t)next(26) << 27) + next(27))
/ (double)(1LL << 53);
}
@@ -56,7 +56,7 @@ double Random::nextGaussian()
{
double v1, v2, s;
do
- {
+ {
v1 = 2 * nextDouble() - 1; // between -1.0 and 1.0
v2 = 2 * nextDouble() - 1; // between -1.0 and 1.0
s = v1 * v1 + v2 * v2;
@@ -79,7 +79,7 @@ int Random::nextInt(int n)
if ((n & -n) == n) // i.e., n is a power of 2
- return (int)(((__int64)next(31) * n) >> 31); // 4J Stu - Made __int64 instead of long
+ return (int)(((int64_t)next(31) * n) >> 31); // 4J Stu - Made int64_t instead of long
int bits, val;
do
@@ -95,9 +95,9 @@ float Random::nextFloat()
return next(24) / ((float)(1 << 24));
}
-__int64 Random::nextLong()
+int64_t Random::nextLong()
{
- return ((__int64)next(32) << 32) + next(32);
+ return ((int64_t)next(32) << 32) + next(32);
}
bool Random::nextBoolean()